@@ -61,6 +61,9 @@ class AnylearnConfig(object):
         workspace : :obj:`str`, optional
             SDK本地存储工作区路径，
             默认将工作区建立在 :obj:`<home>/.anylearn` 目录下。
+        disable_git : :obj:`bool`, optional
+            是否禁用基于本地git的算法同步，
+            默认为否。
         """
         # Cluster Auth
         cls.init_cluster(cluster_address, username, password, token)
