@@ -1,18 +1,18 @@
 from .base import BaseObject
 from .mirror import Mirror
-from .project import Project, ProjectVisibility
+from .project import Project
 from .quota import QuotaGroup
 from .resource import (
     Algorithm,
     AsyncResourceDownloader,
     AsyncResourceUploader,
+    SyncResourceUploader,
     Dataset,
     Model,
     Resource,
     ResourceDownloader,
     ResourceState,
     ResourceUploader,
-    ResourceVisibility,
 )
 from .service import (
     Service,
