@@ -12,21 +12,6 @@ from anylearn.interfaces.base import BaseObject
 from anylearn.interfaces.train_task import TrainTask
 
 
-class ProjectVisibility:
-    """
-    项目可见性标识：
-
-    - -1(HIDDEN)表示不可见
-    - 1(PRIVATE)表示仅创建者可见
-    - 2(PROTECTED)表示所有者可见
-    - 3(PUBLIC)表示公开
-    """
-    HIDDEN = -1
-    PRIVATE = 1
-    PROTECTED = 2
-    PUBLIC = 3
-
-
 class Project(BaseObject):
     """
     AnyLearn项目类，以方法映射项目CRUD相关接口
@@ -39,8 +24,6 @@ class Project(BaseObject):
         项目名称（非空 长度1~50）
     description
         项目描述（可为空 长度最大255）
-    visibility
-        项目的可见性（默认值1）
     create_time
         创建时间
     update_time
@@ -49,8 +32,6 @@ class Project(BaseObject):
         创建者的ID
     datasets
         项目实用的数据集,以逗号分隔数据集的ID拼成的字符串，无多余空格
-    owner
-        项目的所有者，以逗号分隔用户的ID拼成的字符串，无多余空格
     load_detail
         初始化时是否加载详情
     """
@@ -63,10 +44,8 @@ class Project(BaseObject):
         },
         # 资源创建/更新请求包体中包含的所有字段
         'payload': {
-            'create': ['id', 'name', 'description', 'datasets', 'visibility',
-                       'owner'],
-            'update': ['id', 'name', 'description', 'datasets', 'visibility',
-                       'owner'],
+            'create': ['id', 'name', 'description', 'datasets'],
+            'update': ['id', 'name', 'description', 'datasets'],
         },
     }
     """
@@ -80,12 +59,10 @@ class Project(BaseObject):
                  id: Optional[str]=None,
                  name: Optional[str]=None,
                  description: Optional[str]=None,
-                 visibility=1,
                  create_time: Optional[datetime]=None,
                  update_time: Optional[datetime]=None,
                  creator_id: Optional[str]=None,
                  datasets: Optional[list]=None,
-                 owner: Optional[list]=None,
                  load_detail=False):
         """
         Parameters
@@ -96,8 +73,6 @@ class Project(BaseObject):
             项目名称（非空 长度1~50）
         description
             项目描述（可为空 长度最大255）
-        visibility
-            项目的可见性（默认值1）
         create_time
             创建时间
         update_time
@@ -106,20 +81,16 @@ class Project(BaseObject):
             创建者的ID
         datasets
             项目实用的数据集,以逗号分隔数据集的ID拼成的字符串，无多余空格
-        owner
-            项目的所有者，以逗号分隔用户的ID拼成的字符串，无多余空格
         load_detail
             初始化时是否加载详情
         """
         self.id = id
         self.name = name
         self.description = description
-        self.visibility = visibility
         self.create_time = create_time
         self.update_time = update_time
         self.creator_id = creator_id
         self.datasets = datasets
-        self.owner = owner
         super().__init__(id=id, load_detail=load_detail)
 
     def __eq__(self, other: Project) -> bool:
@@ -129,12 +100,10 @@ class Project(BaseObject):
             self.id == other.id,
             self.name == other.name,
             self.description == other.description,
-            # self.visibility == other.visibility,
             # self.create_time == other.create_time,
             # self.update_time == other.update_time,
             # self.creator_id == other.creator_id,
             # self.datasets == other.datasets,
-            # self.owner == other.owner,
         ])
 
     @classmethod
@@ -177,12 +146,10 @@ class Project(BaseObject):
         res = res[0]
         self.__init__(id=res['id'], name=res['name'],
                       description=res['description'],
-                      visibility=res['visibility'],
                       create_time=res['create_time'],
                       update_time=res['update_time'],
                       creator_id=res['creator_id'],
-                      datasets=res['datasets'],
-                      owner=res['owner'])
+                      datasets=res['datasets'])
 
     @classmethod
     def get_my_default_project(cls) -> Project:
@@ -192,12 +159,10 @@ class Project(BaseObject):
         res = res[0]
         return Project(id=res['id'], name=res['name'],
                        description=res['description'],
-                       visibility=res['visibility'],
                        create_time=res['create_time'],
                        update_time=res['update_time'],
                        creator_id=res['creator_id'],
-                       datasets=res['datasets'],
-                       owner=res['owner'])
+                       datasets=res['datasets'])
 
     @classmethod
     def create_my_default_project(cls) -> Project:
