@@ -19,8 +19,8 @@ class File(Resource):
         文件描述（长度最大255）
     state
         文件状态
-    visibility
-        文件的可见性（默认为3）
+    public
+        文件是否公开（默认为False）
     upload_time
         文件上传时间
     filename
@@ -35,8 +35,6 @@ class File(Resource):
         创建者ID
     node_id
         文件节点ID
-    owner
-        文件的所有者，以逗号分隔的这些用户的ID拼成的字符串，无多余空格
     load_detail
         初始化时是否加载详情
     """
@@ -50,9 +48,9 @@ class File(Resource):
         },
         # 资源创建/更新请求包体中包含的所有字段
         'payload': {
-            'create': ['name', 'description', 'visibility', 'owner',
+            'create': ['name', 'description', 'public',
                        'filename'],
-            'update': ['id', 'name', 'description', 'visibility', 'owner'],
+            'update': ['id', 'name', 'description', 'public'],
         },
     }
     """
@@ -67,7 +65,7 @@ class File(Resource):
                  name: Optional[str]=None,
                  description: Optional[str]=None,
                  state: Optional[int]=None,
-                 visibility=1,
+                 public=False,
                  upload_time: Optional[Union[datetime, str]]=None,
                  filename: Optional[str]=None,
                  is_zipfile: Optional[int]=None,
@@ -75,7 +73,6 @@ class File(Resource):
                  size: Optional[str]=None,
                  creator_id: Optional[str]=None,
                  node_id: Optional[str]=None,
-                 owner: Optional[list]=None,
                  load_detail=False):
         """
         Parameters
@@ -88,8 +85,8 @@ class File(Resource):
             文件描述（长度最大255）
         state
             文件状态
-        visibility
-            文件的可见性（默认为1）
+        public
+            文件是否公开（默认为False）
         upload_time
             文件上传时间
         filename
@@ -104,16 +101,14 @@ class File(Resource):
             创建者ID
         node_id
             文件节点ID
-        owner
-            文件的所有者，以逗号分隔的这些用户的ID拼成的字符串，无多余空格
         load_detail
             初始化时是否加载详情
         """
         super().__init__(id=id, name=name, description=description,
-                         state=state, visibility=visibility,
+                         state=state, public=public,
                          upload_time=upload_time, filename=filename,
                          is_zipfile=is_zipfile, file_path=file_path, size=size,
-                         creator_id=creator_id, node_id=node_id, owner=owner,
+                         creator_id=creator_id, node_id=node_id,
                          load_detail=load_detail)
 
     @classmethod
@@ -131,10 +126,9 @@ class File(Resource):
             raise AnyLearnException("请求未能得到有效响应")
         return [
             File(id=f['id'], name=f['name'], description=f['description'],
-                 state=f['state'], visibility=f['visibility'],
+                 state=f['state'], public=f['public'],
                  upload_time=f['upload_time'], filename=f['filename'],
-                 creator_id=f['creator_id'], node_id=f['node_id'],
-                 owner=f['owner'])
+                 creator_id=f['creator_id'], node_id=f['node_id'])
             for f in res
         ]
 
@@ -157,12 +151,11 @@ class File(Resource):
         res = res[0]
         self.__init__(id=res['id'], name=res['name'],
                       description=res['description'], state=res['state'],
-                      visibility=res['visibility'],
+                      public=res['public'],
                       upload_time=res['upload_time'], filename=res['filename'],
                       is_zipfile=True if res['is_zipfile'] == 1 else False,
                       file_path=res['file'], size=res['size'],
-                      creator_id=res['creator_id'], node_id=res['node_id'],
-                      owner=res['owner'])
+                      creator_id=res['creator_id'], node_id=res['node_id'])
 
     def _namespace(self):
         return "file"
